<?xml version="1.0" encoding="UTF-8"?>  
<#-- contents of example -->
<#-- initialise main variables -->
<#-- import common modules -->
<#-- use default front cover -->
<#-- get root entity's name -->
<#-- get structural formula image using *macros_common_general.ftl (substance only) -->
<#-- iterate composition endpoint (substance only) and fetch coposition general name) -->
<#-- get first composition endpoint only (substance only) and fetch coposition name and uuid) -->
<#-- iterate Repeated Dose Toxicity endpoints and fetch their cross-references -->
<#-- use a common module to fetch study information on long-term toxicity to aquatic invertebrates -->
<#-- **TO DO** get category member content from the root entity that is a member of that category -->
<#-- translation of hardcoded text
<#-- example of retrieving a referenced document and field label -->
<#-- get the traversal macro and use it to output a list (of reliability scores) -->



<#-- Import common macros and functions -->
	<#import "common_module_traversal_utils.ftl" as utils>
<#import "macros_common_general.ftl" as com>
<#import "common_module_front_page_docbook.ftl" as fp>
<#import "common_module_environmental_hazard_assessment.ftl" as keyEnvironmentalHazardAssessment>
<#import "macros_common_studies_and_summaries.ftl" as studyandsummaryCom>

<!-- Initialize common variables -->
<@com.initializeMainVariables/>	

<#--------------------------->
<#-- EXAMPLE TEMPLATE FILE -->
<#--------------------------->
<book version="5.0" xmlns="http://docbook.org/ns/docbook" xmlns:xi="http://www.w3.org/2001/XInclude">

	<#-- standard front page structure (note that tags *info *title *cover are mandatory) -->

	<#if isArticle(_subject)>
	<info>
        <title>Main Article</title>
		<cover>
            <para>
				This is some info on the cover page for an Article only
			</para>
        </cover>
    </info>
	
		<#-- all other entity types -->
		<#else>

		<#---------------------------->
		<#-- GET DEFAULT FRONT PAGE -->
		<#---------------------------->

		<@fp.getFrontPage _subject _dossierHeader "my example front page"/>
	
	</#if>
	
	<!-- Part A -->
	<part>
		<title>First part of the document (if needed)</title>
		
		<#-- each chapter is nested inside a *part - note that *part is optional -->
		<chapter label="1">
			<title role="HEAD-1">Basics</title>

			<section>
			<title>Root entity name</title>
				<para>

				<#--------------------------------------------------------------------->
				<#-- use the root entity's document type to output root entity names -->
				<#--------------------------------------------------------------------->

					<#if isSubstance(_subject)>
					Substance name:  <@com.text _subject.ChemicalName/>

						<#elseif isMixture(_subject)>
						Mixture name: <@com.text _subject.MixtureName/>

							<#elseif isCategory(_subject)>
							Category name: <@com.text _subject.CategoryName/>

								<#elseif isArticle(_subject)>
								Article name: <@com.text _subject.Identifiers.ArticleName/>

					</#if>

				</para>
			</section>

			<#------------------------------------------------------------------------------>
			<#-- extract the structural formula from the substance's reference substance --->
			<#-- This uses a path to the reference substance reference and a common macro -->
			<#------------------------------------------------------------------------------>

			<section>
			<title>Reference substance's structural formula</title>
				<#if isSubstance(_subject)>	
				<para>
					<@com.structuralFormula com.getReferenceSubstanceKey(_subject.ReferenceSubstance.ReferenceSubstance) 100 true/>			
				</para>
				</#if>
			</section>
		
		</chapter>
			
		<#---------------------------------------------------------------------------->
		<#-- chapter to show iteration of a composition endpoint and its documents --->
		<#---------------------------------------------------------------------------->

		<chapter label="2">
			<title role="HEAD-1">Simple endpoint iteration</title>
			
				<#if isSubstance(_subject)>

					<#assign compositionList = iuclid.getSectionDocumentsForParentKey(_subject.documentKey, "FLEXIBLE_RECORD", "SubstanceComposition") />
					
					<#if compositionList?has_content>

					<#-- only output the first composition endpoint's document -->
					<#assign compositionRecord = compositionList[0] />

						<table border="1">
							<title>Example table</title>
							<col width="100%" />
							<tbody>
								<tr>
									<th><emphasis role="bold">Composition name</emphasis></th>
								</tr>

								<#-- iterate composition documents with Freemarker #List directive --->
								<#-- a new table row (TR) will appear for every compositon document -->
								<#list compositionList as composition>							
									<tr>
										<td>
											<#-- composition general information name extraction -->
											<@com.text composition.GeneralInformation.Name/>
										</td>
									</tr>
								</#list>

									<tr>
										<td>
											<#-- first composition only -->

											<#-- name of the composition document -->
											<para>First composition name: <@com.text compositionRecord.name/></para>
											
											<#-- uuid of the composition document -->
											<para>First composition uuid: <@com.text compositionRecord.documentKey.uuid/></para>
											
										</td>
									</tr>

							</tbody>
						</table>
					</#if>
				</#if>

		</chapter>

		
		<#--------------------------------->
		<#-- EXAMPLE OF LINKED REFERENCE -->
		<#--------------------------------->
		
		<#if isSubstance(_subject) || isMixture(_subject)>

		<chapter label="3">		
			<title role="HEAD-1">Get a linked reference (in this case, a literature reference in a melting point endpoint)</title>

				<#assign meltingPointList = iuclid.getSectionDocumentsForParentKey(_subject.documentKey, "ENDPOINT_STUDY_RECORD", "Melting") />
				<#if meltingPointList?has_content>
					<#list meltingPointList as meltingPoint>
						<#if meltingPoint?has_content>
							<#list meltingPoint.DataSource.Reference as meltingLiterature>

								<#-- get the document key of the linked reference to access its field data -->
								<#assign meltingPointLiteratureReference = iuclid.getDocumentForKey(meltingLiterature) />
									<#if meltingPointLiteratureReference?has_content>
										<para>
											<#-- get the IUCLID field label name -->
											<@iuclid.label for=meltingPointLiteratureReference.GeneralInfo.LiteratureType var="refType"/>
											This is the actual field label name for the literature reference type: 
											${refType}
										</para>

										
										<para>
											<#--output the reference type -->
											<@com.picklist meltingPointLiteratureReference.GeneralInfo.LiteratureType />
										</para>
									</#if>
							</#list>
						</#if>
					</#list>
				</#if>
				
		</chapter>
		</#if>

		<#------------------------>
		<#-- INBOUND REFERENCES -->
		<#------------------------>

		<#if isSubstance(_subject)>
		<chapter label="4">		
			<title role="HEAD-1">Example of an inbound reference to the Manufacture document</title>			

				<#-- 
				-list through the inbound references of your chosen Endpoints
				-An inbound reference is a reference coming from another document 
				-->			
				
				<#assign manufactureList = iuclid.getSectionDocumentsForParentKey(_subject.documentKey, "FLEXIBLE_RECORD", "Manufacturer") />
				<#if manufactureList?has_content>
				<#list manufactureList as manufacture>
					<#list com.inboundReferences(manufacture.documentKey) as inboundReference>
					
						<#if inboundReference?has_content>
						<#assign inboundReferenceList = iuclid.getDocumentForKey(inboundReference) />
							<#if inboundReferenceList?has_content>

								<#assign manufactureInboundRefURL=iuclid.webUrl.documentView(inboundReferenceList.documentKey) />
								<@iuclid.label for=inboundReferenceList var="referenceFieldLabel"/>
									
										<para>
											${referenceFieldLabel} Name: <@com.text inboundReferenceList.name/>										
											<para>
												${referenceFieldLabel} UUID: <ulink url="${manufactureInboundRefURL}"><@com.text inboundReferenceList.documentKey.uuid/></ulink>
											</para>										
										</para>									

							</#if>
						</#if>
					</#list>
				</#list>
				</#if>
		</chapter>
		</#if>
		
		<#----------------------------------------------------------------------------------------------->
		<#-- CHAPTER TO SHOW ITERATION OF REPEATED DOSE TOXICITY ENDPOINTS AND THEIR CORSS-REFERENCES --->
		<#----------------------------------------------------------------------------------------------->

		<#if isSubstance(_subject) || isMixture(_subject)>

			<chapter label="5">
			<#-- 
			-An example how to get a list of cross references 
			-Source documents are Repeated Dose Toxicity endpoints, showing the name and reason/purpose for cross-reference
			-Target documents are any other ENDPOINT_STUDY_RECORD, showing the name and Endpoint picklist selection
			-->
				<title role="HEAD-1">
				More complex endpoint iteration fetching cross references from Repeated Dose Toxicity endpoints
				</title>

				<#-- firstly, a list of endpoint document types are entered in a hashmap so that we can use these later -->
				<#assign repeatedDoseEndpoints = [] />

				<#assign repeatedDoseEndpoints = 
				{"RepeatedDoseToxicityOral": "RepeatedDoseToxicityOral", 
				"RepeatedDoseToxicityInhalation": "RepeatedDoseToxicityInhalation",
				"RepeatedDoseToxicityDermal": "RepeatedDoseToxicityDermal",
				"RepeatedDoseToxicityOther": "RepeatedDoseToxicityOther"				
				} />
					
				<#if repeatedDoseEndpoints?has_content>

				<#-- macro to create an array of endpoint keys for the endpoints defined above -->
				<@listOfEndpointKeys repeatedDoseEndpoints />

				<#if endpointDocumentKey?has_content>
					<#list endpointDocumentKey as endpoints>				

						<#-- macro to create an array of cross reference items -->	
						<@listOfCrossReferences endpoints/>					
									
							<?linebreak?>
							<para>
								<#-- Information on the Source document for cross-reference -->	
								<#if crossReferenceList?has_content>								
								<emphasis role="bold">Source document</emphasis>
									<para>Name of document
										<emphasis><@com.text endpoints.name /></emphasis>
									</para>
								</#if>

								<#-- Information on the Source and Target document of the cross-reference -->

								<#-- firstly, iterate through the cross-references -->
								<#list crossReferenceList as crossReferences>

								<#-- secondly, get the document key for the cross references -->
								<#assign linkedCrossReferences = iuclid.getDocumentForKey(crossReferences.RelatedInformation)/>	
									<#if linkedCrossReferences?has_content>
										
										<?linebreak?>

										<para role="indent">
										<emphasis role="bold">Target document</emphasis>
										(<@iuclid.label for=crossReferences.ReasonPurpose var="reasonPurpose"/>
										${reasonPurpose}: <@com.picklist crossReferences.ReasonPurpose />)
											<para>Name of document: <emphasis><@com.text linkedCrossReferences.name /></emphasis></para>								
											
											<para><@iuclid.label for=linkedCrossReferences.AdministrativeData.Endpoint var="endpoint"/>
											
											${endpoint}: <emphasis><@com.picklist linkedCrossReferences.AdministrativeData.Endpoint /></emphasis></para>
											
												<#if crossReferences_has_next><para></para></#if>
										</para>

									</#if>
								</#list>
							</para>
					</#list>
				</#if>
				</#if>

				<#-- Macros -->
				<#macro listOfCrossReferences endpoints>

				<#assign crossReferenceList = [] />
				<#assign linkedCrossReferences = [] />

					<#if endpoints.AdministrativeData.CrossReference?has_content>
						<#list endpoints.AdministrativeData.CrossReference as crossReferences>
							<#if crossReferences?has_content>	
							
							<#-- 
							-get the linked cross-reference key
							-check if it has content is of docType ENDPOINT_STUDY_RECORD
							-Output an array of cross-references
							-->

							<#assign linkedCrossReferences = iuclid.getDocumentForKey(crossReferences.RelatedInformation)/>	
								<#if linkedCrossReferences?has_content && linkedCrossReferences.documentType=="ENDPOINT_STUDY_RECORD">							
								<#assign crossReferenceList = crossReferenceList + [crossReferences] />
								</#if>							
							</#if>
						</#list>
					</#if>
				</#macro>

				<#macro listOfEndpointKeys repeatedDoseHashMap>

				<#assign endpointDocumentKey = [] />

					<#if repeatedDoseHashMap?has_content>
					<#list repeatedDoseHashMap?keys as kys>

					<#-- store the hashmap keys in a list *kys* and use this 
					to output all the Repeated Dose Toxicity cross-references -->

					<#assign endpointlist = iuclid.getSectionDocumentsForParentKey(_subject.documentKey, "ENDPOINT_STUDY_RECORD", repeatedDoseHashMap[kys]) />					
						<#list endpointlist as endpoints>					
							<#if endpoints?has_content>
							<#assign endpointDocumentKey = endpointDocumentKey + [endpoints]/>
							</#if>
						</#list>

					</#list>
					</#if>
				</#macro>

			</chapter>
		</#if>

		<#--------------------------->
		<#-- IMPORT COMMON MODULE --->
		<#--------------------------->
		
		<#if isSubstance(_subject) || isMixture(_subject)>
		<chapter label="6">
		
			<title role="HEAD-1">Import a common module - environmental hazard endpoint study </title>
			
			<section>
				<title role="HEAD-4">Long-term toxicity to aquatic invertebrates</title>
				<@keyEnvironmentalHazardAssessment.longTermToxicityToAquaticInvertebratesStudies _subject/>	
			</section>
		
		</chapter>
		</#if>

		<#------------------>
		<#-- TRANSLATIONS -->
		<#------------------>

		<chapter label="7">		
			<title role="HEAD-1">Translated text from property file</title>			

		<#-- assign a variable for each translated text -->
		<#assign textDe = iuclid.text('my_translated_text', 'de', 'localizations') />

			<para>${textDe}</para>
		</chapter>

		<#------------------->
		<#-- LIST APPROACH -->
		<#------------------->

		<#-- Define the main macro to be used to retrieve output by the traversal approach -->
		<#assign mainMacroName = "printIfDocumentTypeIsEndpointStudyRecord"/>
		<#assign mainMacroArgs = ['docElementNode', 'sectionNode', 'entityDocument' 'level']/>

		<#-- Make global the macroCall as well as each macro used in it -->
		<#global mainMacroCall="<@" + mainMacroName + " " + mainMacroArgs?join(" ") + "/>"/>
		<#global printIfDocumentTypeIsEndpointStudyRecord = printIfDocumentTypeIsEndpointStudyRecord/>
		<#global printListOfReliabilityScores = printListOfReliabilityScores/>
		<#global tableOutput=tableOutput/>

		<#-- Counter of list items -->
		<#assign index=0/>

		<#if isSubstance(_subject) || isMixture(_subject)>

		<chapter label="8">
        <title role="HEAD-1">Listing through the IUCLID tree</title>

			<para role="small">

				<#-- Table header -->
				<table border="1">
					<title>Reliability scores</title>

					<col width="10%" />
					<col width="40%" />
					<col width="50%" />

					<tbody>
					<tr>
						<th colspan="1"><?dbfo bgcolor="#d6eaf8" ?><emphasis role="bold">Count studies</emphasis></th>
						<th colspan="1"><?dbfo bgcolor="#d6eaf8" ?><emphasis role="bold">Endpoint name</emphasis></th>
						<th colspan="1"><?dbfo bgcolor="#d6eaf8" ?><emphasis role="bold">Reliability</emphasis></th>
					</tr>

					<#-- Traversal approach: prints one row per reliability score -->
					<@utils.traversal _subject 8/>

					</tbody>
				</table>
			</para>

  		</chapter>
		</#if>
				
			<#-------------------------------------------->
			<#---------- Condition the output ------------>
			<#-------------------------------------------->
			<#macro printIfDocumentTypeIsEndpointStudyRecord docElementNode sectionNode entityDocument level>
				
			<#if level==0>

				<#-- section document key *sectionDoc-->
				<#local sectionDoc = docElementNode?root>

				<#---- Only doc.type ENDPOINT_STUDY_RECORD --->		
				<#---- Only if reliability has content ------->
				<#if sectionDoc.documentType=="ENDPOINT_STUDY_RECORD" && sectionDoc.AdministrativeData.Reliability?has_content>
					<@printListOfReliabilityScores docElementNode sectionDoc sectionNode entityDocument/>
				</#if>
			</#if>

			</#macro>

			<#macro printListOfReliabilityScores fieldNode sectionDoc sectionNode entityDocument>

				<#-- get index count number -->    
				<#assign index=index+1/>

				<#-- Get section name and number of the selected working context -->
				<#local sectionName = "">
				<#if sectionNode?has_content>
					<#if sectionNode.number?has_content>
						<#local sectionName = sectionNode.number + " ">
					</#if>
					<#local sectionName = sectionName + sectionNode.title>
				</#if>
					
				<#-- Get the web URL pointing to the document -->
				<#assign docUrl=utils.getDocumentUrl(sectionDoc) />

				<#-- Provide the rest of the table (tr) and (td) matching the table properties outlined above -->
				<@tableOutput entityDocument sectionName sectionDoc docUrl  />

			</#macro>

			<#macro tableOutput entityDocument sectionName sectionDoc docUrl >
				<tr>				
					<#-- Index -->
					<td>
						${index}
					</td>

					<#-- Endpoint name -->
					<td>
						<@com.text sectionName />
					</td>

					<#-- Reliability -->
					<td>
						<#-- get hyperlink back to document where reliability is found -->
						<ulink url="${docUrl}">		
							<#-- get reliability -->
							<@com.picklist sectionDoc.AdministrativeData.Reliability />
						</ulink>
					</td>
				</tr>
			</#macro>

	</part>

</book>


<#-- Macros and functions -->


<#-- functions to check root entity type -->
<#function isSubstance _subject>
<#if _subject.documentType=="SUBSTANCE">
	<#return true>
<#else>
	<#return false>
</#if>
	<#return false>
</#function>

<#function isMixture _subject>
<#if _subject.documentType=="MIXTURE">
	<#return true>
<#else>
	<#return false>
</#if>
	<#return false>
</#function>

<#function isCategory _subject>
<#if _subject.documentType=="CATEGORY">
	<#return true>
<#else>
	<#return false>
</#if>
	<#return false>
</#function>

<#function isArticle _subject>
<#if _subject.documentType=="ARTICLE">
	<#return true>
<#else>
	<#return false>
</#if>
	<#return false>
</#function>



